# fourier-grx-client

This is the client library for the Fourier GRX robot. 
The correponding server library can be found [here](https://pypi.org/project/fourier-grx/0.1.1rc6/).

## Installation

> [!NOTE] 
    > This software is highly unstable and subject to change at any time. Version 0.1.2 is only compatible with `fourier-grx` version `v0.1.1-rc.6`.


### On the robot

On the robot, install `fourier-grx==0.1.0rc6` following the instructions [here](https://github.com/FFTAI/Wiki-GRx-Deploy/tree/0.1.0rc6).

### On your local machine:

Run:

```bash
pip install fourier-grx-client==0.1.2
```